#
# spec file for package libmfx
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 1
Name:           libmfx
%define lname   libmfx%{sover}
Version:        21.3.4
Release:        150400.3.2.2
Summary:        The Intel Media SDK
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/Intel-Media-SDK/MediaSDK
Source0:        https://github.com/Intel-Media-SDK/MediaSDK/archive/intel-mediasdk-%{version}.tar.gz
Patch0:         cmake-sle12.patch
BuildRequires:  cmake
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(wayland-client)
ExclusiveArch:  x86_64

%description
The Intel Media SDK provides a plain C API to access hardware-accelerated
video decode, encode and filtering on Intel Gen graphics hardware
platforms. The implementation is written in C++11, with parts in C-for-Media
(CM).

%package -n %lname
Summary:        The Intel Media SDK
Group:          System/Libraries

%description -n %lname
The Intel Media SDK provides a plain C API to access hardware-accelerated
video decode, encode and filtering on Intel Gen graphics hardware
platforms. The implementation is written in C++11, with parts in C-for-Media
(CM).

%package devel
Summary:        Development files Intel Media SDK
Group:          Development/Languages/C and C++
Requires:       %lname = %version

%description devel
This package contains the development headers and pkgconfig files for
the Intel Media SDK.

%package samples
Summary:        Examples for the Intel Media SDK
Group:          Development/Languages/C and C++

%description samples
This package contains example applications for the Intel Media SDK.

%prep
%autosetup -p1 -n MediaSDK-intel-mediasdk-%{version}

%build
mkdir -p build 
pushd build
# libITT and cm compiler not available on openSUSE
cmake \
%if 0%{?suse_version} < 1500
-DCMAKE_CXX_COMPILER="%{_bindir}/g++-7" \
%endif
-DCMAKE_INSTALL_PREFIX="%{_prefix}" \
-DENABLE_X11_DRI3:BOOL=ON \
-DENABLE_WAYLAND:BOOL=ON \
-DENABLE_TEXTLOG:BOOL=ON \
-DENABLE_STAT:BOOL=ON \
-DBUILD_TESTS:BOOL=OFF \
-DBUILD_TOOLS:BOOL=ON \
-DENABLE_ITT:BOOL=OFF \
-DBUILD_KERNELS:BOOL=OFF \
..
make %{?_smp_mflags}
popd

%install
pushd build
%make_install
popd
mkdir -p %{buildroot}/%{_libdir}/mfx/samples
mv %{buildroot}/%{_datadir}/mfx/samples/* \
   %{buildroot}/%{_libdir}/mfx/samples
rmdir %{buildroot}/%{_datadir}/mfx/samples

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%doc CHANGELOG.md CODEOWNERS README.rst
%{_bindir}/asg-hevc
%{_bindir}/hevc_fei_extractor
%{_bindir}/mfx-tracer-config

%files -n %lname
%license LICENSE 
%{_libdir}/libmfx.so.%{sover}
%{_libdir}/libmfx.so.%{sover}.*
%{_libdir}/libmfxhw64.so.%{sover}
%{_libdir}/libmfxhw64.so.%{sover}.*
%{_libdir}/libmfx-tracer.so.%{sover}
%{_libdir}/libmfx-tracer.so.%{sover}.*
%dir %{_libdir}/mfx
%{_libdir}/mfx/libmfx_*_hw64.so
%dir %{_datadir}/mfx
%{_datadir}/mfx/plugins.cfg

%files samples
%{_libdir}/mfx/samples/

%files devel
%{_includedir}/mfx/
%{_libdir}/libmfx.so
%{_libdir}/libmfxhw64.so
%{_libdir}/libmfx-tracer.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Oct  4 2021 sndirsch@suse.com
- fixed JIRA number in previous changelog
* Wed Sep 29 2021 sndirsch@suse.com
- Update to 21.3.4
  * Fixed VPL run-time loading by MediaSDK dispatcher
    VPL doesn't provide libmfx-gen.so.1
    In VPL Gen run-time we have libmfx-gen.so.1.2 as SONAME and
    use libmfx-gen.so.1.2.x as a full name.
  * [VPP] Fix increasing num of input channels doesn't work
  * maximum and minmum qp setting for HEVC encoder.
  * Removed multiple calls vaGetConfigAttributes (github
    issue#2417)
  * [Jpeg]modify color range on Linux
  * [Jpegd] Enable HW to decode JPEG RGB444 on Linux
* Mon Sep 27 2021 sndirsch@suse.com
- covers jira#SLE/SLE-19361
* Wed Sep 22 2021 sndirsch@suse.com
- Update to 21.3.3
  * latest version
- refreshed cmake-sle12.patch
- supersedes u_gcc11.patch
* Wed Feb 10 2021 sndirsch@suse.com
- u_gcc11.patch
  * fixes build against gcc11 (boo#1181871)
* Sat Oct 10 2020 dmueller@suse.com
- update to 20.3.0:
  * Added Keem Bay platform support
  * Added AV1 decode support
  * Added implicit Motion-Compensated Temporal Filter (MCTF) to improve coding quality on certain scenarios
  * Improved CodecLevel initialization from rate control parameters
  * Added support of 4k streams with look-ahead bitrate control mode
  * Enabled QPOffset by default
  * Improved efficiency of FPQ
  * Enabled QP modulation (Icelake+)
  * Added 16k support
  * Added A2RGB10 input in case of passthru copy
  * Added -dec::sys flag for setting of the output memory to system type in sample_multi_transcode
  * Added p016/y216 support in sample_encode
  * Added i420/nv12 support in sample_multi_transcode
  * Fixed chroma size for Y210/Y216 formats in sample_deocde
  * Added handle for iterpolation methods for resize in sample_vpp
  * Added support for discrete Intel Xe graphics codenamed DG1 and SG1
  * Added support for Rocketlake platform
  * Actualized Elkhartlake device id support list
* Mon Aug 31 2020 sndirsch@suse.com
- version 20.2.1 needed for jira#SLE/SLE-12712
* Thu Aug 27 2020 sndirsch@suse.com
- Update to version 20.2.1
  * Samples: Fixed #2190. rotate_opencl plugin switched to recent
    version of OpenCL C++ headers, validated with OpenCL-CLHPP
    v2.0.12 and OpenCL-Headers v2020.06.16 / Intel® SDK for OpenCL™
    Applications for Windows* 2020.2.487.
* Thu Aug 27 2020 sndirsch@suse.com
- Update to version 20.2.0
  * bugfixes and improvements
  * includes: Build system does not enforce specific instruction
    set (issue#2047, boo#1167346)
- supersedes u_buildfix-for-gcc10.patch
* Mon Aug  3 2020 fvogt@suse.com
- Move samples into a new subpackage
- The library does not depend on the tools, drop Requires
- Apply patch unconditionally, use %%autosetup
- Move LICENSE to library package
- Make the sover part of %%files
- Don't bother building tests, they're not run anyway
* Mon Mar 16 2020 sndirsch@suse.com
- u_buildfix-for-gcc10.patch
  * fixes build against gcc10 (boo#1166609)
* Tue Mar  3 2020 bjorn.lie@gmail.com
- Update to version 19.4.0:
  * bugfixes and improvements
* Thu Nov  7 2019 sndirsch@suse.com
- This release fullfills requirements for jsc#SLE-8841
* Tue Sep  3 2019 sndirsch@suse.com
- Update to release 19.2.1
  * bugfixes and improvements
* Mon Aug 26 2019 jengelh@inai.de
- More consistent macro usage throughout.
- Grammar fixes to description.
* Tue Jun 11 2019 sndirsch@suse.com
- added more features to build
  * X11_DRI3
  * WAYLAND
  * TEXTLOG
  * STAT
  * TESTS
  * TOOLS
- ITT and KERNELS features remain disabled for now since libITT
  and cm compiler is not available on (open)SUSE right now
- gcc7 needed for building tests on sle12-sp5
- moved documentation and binaries to main package; let require
  the library subpackage the main package
* Fri Jun  7 2019 sndirsch@suse.com
- cmake-sle12.patch
  * needed for cmake 3.5.2 on sle12-sp5
* Thu Jun  6 2019 sndirsch@suse.com
- created package for Intel Media SDK (jira #SLE-4968, bsc#1137651)
